import { Authenticated, Refine } from "@refinedev/core";
import { DevtoolsPanel, DevtoolsProvider } from "@refinedev/devtools";
import { RefineKbar, RefineKbarProvider } from "@refinedev/kbar";

import {
  ErrorComponent,
  ThemedLayoutV2,
  ThemedSiderV2,
  useNotificationProvider,
} from "@refinedev/antd";
import "@refinedev/antd/dist/reset.css";

import routerBindings, {
  CatchAllNavigate,
  DocumentTitleHandler,
  NavigateToResource,
  UnsavedChangesNotifier,
} from "@refinedev/react-router";
import { App as AntdApp } from "antd";
import { BrowserRouter, Outlet, Route, Routes } from "react-router";
import { authProvider } from "./authProvider";
import { Header } from "./components/header";
import { ColorModeContextProvider } from "./contexts/color-mode";
import { API_URL } from "./config";
import { customDataProvider } from "./dataProvider";

// Import our custom pages
import {
  DeploymentList,
  DeploymentCreate,
  DeploymentShow,
} from "./pages/deployments";
import {
  AppList,
  AppCreate,
  AppShow,
} from "./pages/apps";
import {
  ComponentList,
  ComponentCreate,
  ComponentShow,
  ComponentEdit,
  ComponentDeployments,
} from "./pages/components";
import {
  ClientCreate,
  ClientList,
  ClientShow,
} from "./pages/clients";
import {
  MonitoringDashboard,
} from "./pages/monitoring";
import {
  SupportTickets,
} from "./pages/support";
import {
  DashboardOverview,
} from "./pages/dashboard";
import {
  SetupWizard,
} from "./pages/setup";
import { Profile } from "./pages/profile";
import { Settings } from "./pages/settings";
import { Notifications } from "./pages/notifications";

import { ForgotPassword } from "./pages/forgotPassword";
import { Login } from "./pages/login";
import { Register } from "./pages/register";
import { 
  DashboardOutlined, 
  AppstoreOutlined, 
  RocketOutlined,
  ThunderboltOutlined,
  CodeOutlined,
  TeamOutlined,
  BarChartOutlined,
  QuestionCircleOutlined
} from "@ant-design/icons";

function App() {
  const apiUrl = API_URL || "http://localhost:8080/api/v1";

  return (
    <BrowserRouter>
      <RefineKbarProvider>
        <ColorModeContextProvider>
          <AntdApp>
            <DevtoolsProvider>
              <Refine
                dataProvider={customDataProvider(apiUrl)}
                notificationProvider={useNotificationProvider}
                routerProvider={routerBindings}
                authProvider={authProvider}
                resources={[
                  {
                    name: "dashboard",
                    list: "/dashboard",
                    meta: {
                      icon: <DashboardOutlined />,
                      label: "Dashboard",
                    },
                  },
                  {
                    name: "setup",
                    list: "/setup",
                    meta: {
                      icon: <ThunderboltOutlined />,
                      label: "Quick Setup",
                    },
                  },
                  {
                    name: "deployments",
                    list: "/deployments",
                    create: "/deployments/create",
                    show: "/deployments/show/:id",
                    meta: {
                      canDelete: true,
                      icon: <RocketOutlined />,
                      label: "Deployments",
                    },
                  },
                  {
                    name: "apps",
                    list: "/apps",
                    create: "/apps/create",
                    show: "/apps/show/:id",
                    meta: {
                      canDelete: true,
                      icon: <CodeOutlined />,
                      label: "Apps",
                    },
                  },
                  {
                    name: "components",
                    list: "/components",
                    create: "/components/create",
                    show: "/components/show/:id",
                    edit: "/components/edit/:id",
                    meta: {
                      canDelete: true,
                      icon: <AppstoreOutlined />,
                      label: "Components",
                    },
                  },
                  {
                    name: "clients",
                    list: "/clients",
                    create: "/clients/create",
                    show: "/clients/show/:id",
                    meta: {
                      canDelete: true,
                      icon: <TeamOutlined />,
                      label: "Clients",
                    },
                  },
                  {
                    name: "monitoring",
                    list: "/monitoring",
                    meta: {
                      icon: <BarChartOutlined />,
                      label: "Monitoring",
                    },
                  },
                  {
                    name: "support",
                    list: "/support",
                    meta: {
                      icon: <QuestionCircleOutlined />,
                      label: "Support Tickets",
                    },
                  },
                ]}
                options={{
                  syncWithLocation: true,
                  warnWhenUnsavedChanges: true,
                  useNewQueryKeys: true,
                }}
              >
                <Routes>
                  <Route
                    element={
                      <Authenticated
                        key="authenticated-inner"
                        fallback={<CatchAllNavigate to="/login" />}
                      >
                        <ThemedLayoutV2
                          Header={Header}
                          Sider={(props) => (
                            <ThemedSiderV2
                              {...props}
                              fixed
                              Title={() => <span>BYOP Dashboard</span>}
                            />
                          )}
                        >
                          <Outlet />
                        </ThemedLayoutV2>
                      </Authenticated>
                    }
                  >
                    <Route
                      index
                      element={<NavigateToResource resource="dashboard" />}
                    />
                    <Route path="/dashboard">
                      <Route index element={<DashboardOverview />} />
                    </Route>
                    <Route path="/setup">
                      <Route index element={<SetupWizard />} />
                      <Route path="wizard" element={<SetupWizard />} />
                    </Route>
                    <Route path="/deployments">
                      <Route index element={<DeploymentList />} />
                      <Route path="create" element={<DeploymentCreate />} />
                      <Route path="show/:id" element={<DeploymentShow />} />
                    </Route>
                    <Route path="/apps">
                      <Route index element={<AppList />} />
                      <Route path="create" element={<AppCreate />} />
                      <Route path="show/:id" element={<AppShow />} />
                    </Route>
                    <Route path="/components">
                      <Route index element={<ComponentList />} />
                      <Route path="create" element={<ComponentCreate />} />
                      <Route path="show/:id" element={<ComponentShow />} />
                      <Route path="edit/:id" element={<ComponentEdit />} />
                      <Route path=":id/deployments" element={<ComponentDeployments />} />
                    </Route>
                    <Route path="/clients">
                      <Route index element={<ClientList />} />
                      <Route path="create" element={<ClientCreate />} />
                      <Route path="show/:id" element={<ClientShow />} />
                    </Route>
                    <Route path="/monitoring">
                      <Route index element={<MonitoringDashboard />} />
                    </Route>
                    <Route path="/support">
                      <Route index element={<SupportTickets />} />
                    </Route>
                    <Route path="/profile" element={<Profile />} />
                    <Route path="/settings" element={<Settings />} />
                    <Route path="/notifications" element={<Notifications />} />
                    <Route path="*" element={<ErrorComponent />} />
                  </Route>
                  <Route
                    element={
                      <Authenticated
                        key="authenticated-outer"
                        fallback={<Outlet />}
                      >
                        <NavigateToResource />
                      </Authenticated>
                    }
                  >
                    <Route path="/login" element={<Login />} />
                    <Route path="/register" element={<Register />} />
                    <Route
                      path="/forgot-password"
                      element={<ForgotPassword />}
                    />
                  </Route>
                </Routes>

                <RefineKbar />
                <UnsavedChangesNotifier />
                <DocumentTitleHandler />
              </Refine>
              <DevtoolsPanel />
            </DevtoolsProvider>
          </AntdApp>
        </ColorModeContextProvider>
      </RefineKbarProvider>
    </BrowserRouter>
  );
}

export default App;
