import type { AuthProvider } from "@refinedev/core";
import axios, { AxiosError } from "axios";
import { API_URL } from "./config";

export const TOKEN_KEY = "byop-auth";
export const REFRESH_TOKEN_KEY = "byop-refresh";
export const USER_KEY = "byop-user";

export const authProvider: AuthProvider = {
  login: async ({ email, password }) => {
    if (!email || !password) {
      return {
        success: false,
        error: {
          name: "LoginError",
          message: "Email and password are required",
        },
      };
    }

    try {
      const response = await axios.post(`${API_URL}/login`, {
        email,
        password,
      });

      if (response.data && response.data.access_token) {
        // Store auth tokens
        localStorage.setItem(TOKEN_KEY, response.data.access_token);
        
        // Store refresh token if available
        if (response.data.refresh_token) {
          localStorage.setItem(REFRESH_TOKEN_KEY, response.data.refresh_token);
        }
        
        // Store user info
        // Assuming the backend might send user details in a nested 'user' object or top-level
        const userPayload = {
          id: response.data.user_id,
          role: response.data.user_role,
          // Add other user fields if available in response, e.g., username, email
          // username: response.data.username, 
          // email: response.data.email,
        };
        localStorage.setItem(USER_KEY, JSON.stringify(userPayload));
        
        return {
          success: true,
          redirectTo: "/",
        };
      }

      return {
        success: false,
        error: {
          name: "LoginError",
          message: "Invalid response from server",
        },
      };
    } catch (error) {
      const axiosError = error as AxiosError;
      const errorMessage = 
        (axiosError.response?.data as { message?: string })?.message || 
        "Something went wrong. Please try again.";
        
      return {
        success: false,
        error: {
          name: "LoginError",
          message: errorMessage,
        },
      };
    }
  },

  register: async ({ username, email, password }) => {
    if (!username || !email || !password) {
      return {
        success: false,
        error: {
          name: "RegisterError",
          message: "Username, email, and password are required",
        },
      };
    }

    try {
      const response = await axios.post(`${API_URL}/users`, {
        username,
        email,
        password,
        preferences: {
          theme: "light",
          notifications: true,
        },
      });

      if (response.status === 201 || response.status === 200) {
        return {
          success: true,
          redirectTo: "/login",
        };
      }

      return {
        success: false,
        error: {
          name: "RegisterError",
          message: "Registration failed",
        },
      };
    } catch (error) {
      const axiosError = error as AxiosError;
      const errorMessage = 
      (axiosError.response?.data as { message?: string })?.message || 
      "Something went wrong. Please try again.";
      
      return {
        success: false,
        error: {
          name: "RegisterError",
          message: errorMessage,
        },
      };
    }
  },

  forgotPassword: async ({ email }) => {
    if (!email) {
      return {
        success: false,
        error: {
          name: "ForgotPasswordError",
          message: "Email is required",
        },
      };
    }

    try {
      // Assuming your backend has a forgot-password endpoint
      await axios.post(`${API_URL}/forgot-password`, { email });
      
      return {
        success: true,
      };
    } catch (error) {
      const axiosError = error as AxiosError;
      const errorMessage = 
      (axiosError.response?.data as { message?: string })?.message || 
      "Something went wrong. Please try again.";
      
      return {
        success: false,
        error: {
          name: "ForgotPasswordError",
          message: errorMessage,
        },
      };
    }
  },

  logout: async () => {
    try {
      // Call logout API endpoint with the current token
      const token = localStorage.getItem(TOKEN_KEY);
      if (token) {
        await axios.post(
          `${API_URL}/logout`,
          {},
          {
            headers: {
              Authorization: `Bearer ${token}`,
            },
          }
        );
      }
    } catch (error) {
      console.error("Logout error:", error);
    } finally {
      // Clear all auth-related storage
      localStorage.removeItem(TOKEN_KEY);
      localStorage.removeItem(REFRESH_TOKEN_KEY);
      localStorage.removeItem(USER_KEY);
    }
    
    return {
      success: true,
      redirectTo: "/login",
    };
  },

  check: async () => {
    const token = localStorage.getItem(TOKEN_KEY);
    if (!token) {
      return {
        authenticated: false,
        redirectTo: "/login",
      };
    }

    try {
      // You could verify the token here by calling a protected endpoint
      // Or just rely on the token's existence
      return {
        authenticated: true,
      };
    } catch (error) {
      return {
        authenticated: false,
        redirectTo: "/login",
      };
    }
  },

  getPermissions: async () => {
    const user = localStorage.getItem(USER_KEY);
    if (user) {
      const parsedUser = JSON.parse(user);
      return parsedUser.role;
    }
    return null;
  },

  getIdentity: async () => {
    const user = localStorage.getItem(USER_KEY);
    if (user) {
      const parsedUser = JSON.parse(user);
      return {
        id: parsedUser.id,
        name: parsedUser.username,
        email: parsedUser.email,
        role: parsedUser.role,
        avatar: `https://ui-avatars.com/api/?name=${encodeURIComponent(parsedUser.username)}`,
        preferences: parsedUser.preferences,
      };
    }
    return null;
  },

  onError: async (error) => {
    const status = error?.response?.status;
    
    if (status === 401) {
      // Handle token expiration
      const refreshToken = localStorage.getItem(REFRESH_TOKEN_KEY);
      
      if (refreshToken) {
        try {
          // Try to refresh the token
          const response = await axios.post(`${API_URL}/refresh-token`, {
            refreshToken,
          });
          
          if (response.data && response.data.token) {
            // Update the token
            localStorage.setItem(TOKEN_KEY, response.data.token);
            
            // Return to prevent redirecting to login
            return {
              error,
              logout: false,
            };
          }
        } catch (refreshError) {
          // If refresh fails, clear tokens and redirect to login
          localStorage.removeItem(TOKEN_KEY);
          localStorage.removeItem(REFRESH_TOKEN_KEY);
          localStorage.removeItem(USER_KEY);
          
          return {
            error,
            logout: true,
            redirectTo: "/login",
          };
        }
      }
      
      return {
        error,
        logout: true,
        redirectTo: "/login",
      };
    }
    
    // Handle other errors
    console.error("API Error:", error);
    return { error };
  },
};
