import React, { useState } from 'react';
import { Button, message, Modal } from 'antd';
import { RocketOutlined, LoadingOutlined } from '@ant-design/icons';
import { useCustomMutation } from '@refinedev/core';
import { Component } from '../types/component';

interface ComponentBuildControlProps {
  component: Component;
  onBuildStart?: () => void;
}

export const ComponentBuildControl: React.FC<ComponentBuildControlProps> = ({ 
  component, 
  onBuildStart 
}) => {
  const [isBuilding, setIsBuilding] = useState(false);
  
  const { mutate: triggerBuild } = useCustomMutation();

  const handleBuildClick = () => {
    Modal.confirm({
      title: 'Build Component',
      content: `Are you sure you want to build component "${component.name}"? This will create a new container image.`,
      okText: 'Build',
      cancelText: 'Cancel',
      onOk: () => {
        setIsBuilding(true);
        triggerBuild(
          {
            url: `/components/${component.id}/build`,
            method: 'post',
            values: {},
          },
          {
            onSuccess: () => {
              message.success('Build started successfully');
              onBuildStart?.();
            },
            onError: (error: any) => {
              message.error(`Failed to start build: ${error.message}`);
            },
            onSettled: () => {
              setIsBuilding(false);
            }
          }
        );
      }
    });
  };

  const canBuild = component.status === 'valid' || component.status === 'ready';
  const isCurrentlyBuilding = component.status === 'building' || isBuilding;

  if (!canBuild && !isCurrentlyBuilding) {
    return null;
  }

  return (
    <Button 
      type="primary" 
      icon={isCurrentlyBuilding ? <LoadingOutlined /> : <RocketOutlined />}
      onClick={handleBuildClick}
      disabled={isCurrentlyBuilding}
      loading={isBuilding}
    >
      {isCurrentlyBuilding ? 'Building...' : 'Build Component'}
    </Button>
  );
};
