import React, { useState, useEffect } from 'react';
import { Spin } from 'antd';
import { LoadingOutlined } from '@ant-design/icons';
import { ComponentStatusBadge } from './ValidationStatusBadge';
import { ComponentStatus } from '../types/component';
import { API_URL } from '../config';

interface ComponentStatusDisplayProps {
  componentId: number;
  size?: 'default' | 'small';
}

interface Component {
  id: number;
  name: string;
  status: string;
  error_msg?: string;
  type: string;
  repository: string;
  branch: string;
}

export const ComponentStatusDisplay: React.FC<ComponentStatusDisplayProps> = ({ 
  componentId, 
  size = 'default' 
}) => {
  const [component, setComponent] = useState<Component | null>(null);
  const [isLoading, setIsLoading] = useState(false);

  const fetchComponentStatus = async () => {
    setIsLoading(true);
    try {
      const token = localStorage.getItem('auth-token');
      const response = await fetch(`${API_URL}/components/${componentId}`, {
        headers: {
          'Authorization': `Bearer ${token}`,
          'Content-Type': 'application/json',
        },
      });
      if (response.ok) {
        const data = await response.json();
        setComponent(data);
      }
    } catch (error) {
      console.error('Error fetching component status:', error);
    } finally {
      setIsLoading(false);
    }
  };

  useEffect(() => {
    if (componentId) {
      fetchComponentStatus();
    }
  }, [componentId]);

  // Set up polling for async operations
  useEffect(() => {
    if (!component?.status) return;

    // Only set up interval if component is in async state
    if (component.status === 'validating' || component.status === 'building') {
      const interval = setInterval(() => {
        fetchComponentStatus();
      }, 3000);

      return () => clearInterval(interval);
    }
  }, [component?.status]);

  if (isLoading && !component) {
    // For initial loading, show loading spinner
    return <Spin indicator={<LoadingOutlined style={{ fontSize: 14 }} spin />} />;
  }

  if (!component) {
    return <Spin indicator={<LoadingOutlined style={{ fontSize: 14 }} spin />} />;
  }

  return (
    <ComponentStatusBadge 
      status={component.status as ComponentStatus} 
      errorMessage={component.error_msg}
      size={size}
    />
  );
};
