import React, { useState, useEffect } from 'react';
import { Card, Button, Space, Typography, Alert, Progress, Modal, Input, message } from 'antd';
import { 
  PlayCircleOutlined, 
  StopOutlined, 
  LinkOutlined,
  FileTextOutlined,
  ReloadOutlined
} from '@ant-design/icons';
import { PreviewStatusBadge } from './PreviewStatusBadge';
import { Preview } from '../types/preview';
import { API_URL } from '../config';

const { Title, Text } = Typography;
const { TextArea } = Input;

interface PreviewControlProps {
  appId: number;
  appName: string;
}

export const PreviewControl: React.FC<PreviewControlProps> = ({ appId, appName }) => {
  const [logsVisible, setLogsVisible] = useState(false);
  const [logs, setLogs] = useState<string>('');
  const [isCreating, setIsCreating] = useState(false);
  const [isStopping, setIsStopping] = useState(false);
  const [previewData, setPreviewData] = useState<Preview | null>(null);
  const [isLoading, setIsLoading] = useState(false);

  // Fetch preview status
  const fetchPreviewStatus = async () => {
    setIsLoading(true);
    try {
      const response = await fetch(`${API_URL}/apps/${appId}/preview`);
      if (response.ok) {
        const data = await response.json();
        setPreviewData(data);
      } else if (response.status === 404) {
        // No preview exists, this is normal
        setPreviewData(null);
      } else {
        console.error('Failed to fetch preview status');
      }
    } catch (error) {
      console.error('Error fetching preview status:', error);
    } finally {
      setIsLoading(false);
    }
  };

  // Initial load and refetch function
  useEffect(() => {
    fetchPreviewStatus();
  }, [appId]);

  const refetch = fetchPreviewStatus;

  // Manual API calls for create/stop preview
  const createPreview = async () => {
    setIsCreating(true);
    try {
      const response = await fetch(`${API_URL}/apps/${appId}/preview`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
      });
      
      if (response.ok) {
        message.success('Preview started successfully!');
        refetch();
      } else {
        message.error('Failed to start preview');
      }
    } catch (error) {
      message.error('Failed to start preview');
    } finally {
      setIsCreating(false);
    }
  };

  const stopPreview = async () => {
    setIsStopping(true);
    try {
      const response = await fetch(`${API_URL}/apps/${appId}/preview`, {
        method: 'DELETE',
        headers: {
          'Content-Type': 'application/json',
        },
      });
      
      if (response.ok) {
        message.success('Preview stopped successfully!');
        refetch();
      } else {
        message.error('Failed to stop preview');
      }
    } catch (error) {
      message.error('Failed to stop preview');
    } finally {
      setIsStopping(false);
    }
  };

  // Auto-refresh preview status when building/deploying
  useEffect(() => {
    if (previewData && (previewData.status === 'building' || previewData.status === 'deploying')) {
      const interval = setInterval(() => {
        refetch();
      }, 3000); // Refresh every 3 seconds

      return () => clearInterval(interval);
    }
  }, [previewData?.status, refetch]);

  const preview = previewData;
  const isActive = preview && ['building', 'deploying', 'running'].includes(preview.status);
  const canStart = !preview || preview.status === 'stopped' || preview.status === 'failed';
  const canStop = preview && ['building', 'deploying', 'running'].includes(preview.status);
  const canOpenPreview = preview?.status === 'running' && preview.url;

  const getProgressPercent = () => {
    if (!preview) return 0;
    switch (preview.status) {
      case 'building': return 30;
      case 'deploying': return 70;
      case 'running': return 100;
      case 'failed':
      case 'stopped': return 0;
      default: return 0;
    }
  };

  const getProgressStatus = () => {
    if (!preview) return 'normal';
    switch (preview.status) {
      case 'building':
      case 'deploying': return 'active';
      case 'running': return 'success';
      case 'failed': return 'exception';
      default: return 'normal';
    }
  };

  const handleShowLogs = async () => {
    setLogsVisible(true);
    try {
      const response = await fetch(`${API_URL}/apps/${appId}/preview/logs`);
      if (response.ok) {
        const data = await response.text();
        setLogs(data || 'No logs available');
      } else {
        setLogs('Failed to fetch logs');
      }
    } catch (error) {
      setLogs('Error fetching logs');
    }
  };

  const refreshLogs = async () => {
    try {
      const response = await fetch(`${API_URL}/apps/${appId}/preview/logs`);
      if (response.ok) {
        const data = await response.text();
        setLogs(data || 'No logs available');
      } else {
        setLogs('Failed to fetch logs');
      }
    } catch (error) {
      setLogs('Error fetching logs');
    }
  };

  const generatePreviewUrl = () => {
    if (preview?.url) return preview.url;
    
    // Fallback URL generation
    const cleanAppName = appName.toLowerCase().replace(/[^a-z0-9]/g, '-');
    return `http://${cleanAppName}-preview-${appId}.byop.local`;
  };

  return (
    <Card 
      title="Application Preview" 
      size="small"
      extra={
        <Button 
          icon={<ReloadOutlined />} 
          onClick={() => refetch()} 
          loading={isLoading}
          size="small"
        />
      }
    >
      <Space direction="vertical" style={{ width: '100%' }} size="middle">
        {/* Status Display */}
        <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
          <div>
            <Text strong>Status: </Text>
            {preview ? (
              <PreviewStatusBadge 
                status={preview.status} 
                errorMessage={preview.error_message}
                size="small"
              />
            ) : (
              <Text type="secondary">No preview available</Text>
            )}
          </div>
          
          {preview && (
            <Text type="secondary" style={{ fontSize: '12px' }}>
              Expires: {new Date(preview.expires_at).toLocaleString()}
            </Text>
          )}
        </div>

        {/* Progress Bar */}
        {isActive && (
          <Progress 
            percent={getProgressPercent()} 
            status={getProgressStatus()}
            size="small"
            showInfo={false}
          />
        )}

        {/* Error Message */}
        {preview?.status === 'failed' && preview.error_message && (
          <Alert 
            message="Preview Failed" 
            description={preview.error_message}
            type="error" 
            showIcon 
          />
        )}

        {/* Preview URL */}
        {canOpenPreview && (
          <div style={{ padding: '8px', background: '#f6ffed', border: '1px solid #b7eb8f', borderRadius: '4px' }}>
            <Text strong style={{ color: '#52c41a' }}>Preview URL: </Text>
            <a 
              href={generatePreviewUrl()} 
              target="_blank" 
              rel="noopener noreferrer"
              style={{ wordBreak: 'break-all' }}
            >
              {generatePreviewUrl()}
            </a>
          </div>
        )}

        {/* Action Buttons */}
        <Space>
          {canStart && (
            <Button 
              type="primary" 
              icon={<PlayCircleOutlined />}
              onClick={createPreview}
              loading={isCreating}
              size="small"
            >
              Start Preview
            </Button>
          )}
          
          {canStop && (
            <Button 
              danger
              icon={<StopOutlined />}
              onClick={stopPreview}
              loading={isStopping}
              size="small"
            >
              Stop Preview
            </Button>
          )}
          
          {canOpenPreview && (
            <Button 
              icon={<LinkOutlined />}
              onClick={() => window.open(generatePreviewUrl(), '_blank')}
              size="small"
            >
              Open Preview
            </Button>
          )}
          
          {preview && (
            <Button 
              icon={<FileTextOutlined />}
              onClick={handleShowLogs}
              size="small"
            >
              View Logs
            </Button>
          )}
        </Space>
      </Space>

      {/* Logs Modal */}
      <Modal
        title="Preview Logs"
        open={logsVisible}
        onCancel={() => setLogsVisible(false)}
        footer={[
          <Button key="refresh" onClick={refreshLogs}>
            Refresh Logs
          </Button>,
          <Button key="close" onClick={() => setLogsVisible(false)}>
            Close
          </Button>
        ]}
        width={800}
      >
        <TextArea
          value={logs}
          readOnly
          rows={20}
          style={{ fontFamily: 'monospace', fontSize: '12px' }}
          placeholder="Loading logs..."
        />
      </Modal>
    </Card>
  );
};
