import React, { useState, useEffect } from 'react';
import { Button, Tooltip, Spin } from 'antd';
import { LinkOutlined, LoadingOutlined } from '@ant-design/icons';
import { PreviewStatusBadge } from './PreviewStatusBadge';
import { Preview } from '../types/preview';
import { API_URL } from '../config';

interface PreviewStatusColumnProps {
  appId: number;
  appName: string;
}

export const PreviewStatusColumn: React.FC<PreviewStatusColumnProps> = ({ appId, appName }) => {
  const [previewData, setPreviewData] = useState<Preview | null>(null);
  const [isLoading, setIsLoading] = useState(false);

  // Fetch preview status
  const fetchPreviewStatus = async () => {
    setIsLoading(true);
    try {
      const response = await fetch(`${API_URL}/apps/${appId}/preview`);
      if (response.ok) {
        const data = await response.json();
        setPreviewData(data);
      } else if (response.status === 404) {
        // No preview exists, this is normal
        setPreviewData(null);
      }
    } catch (error) {
      console.error('Error fetching preview status:', error);
    } finally {
      setIsLoading(false);
    }
  };

  useEffect(() => {
    fetchPreviewStatus();
  }, [appId]);

  const generatePreviewUrl = () => {
    if (previewData?.url) return previewData.url;
    
    // Fallback URL generation
    const cleanAppName = appName.toLowerCase().replace(/[^a-z0-9]/g, '-');
    return `http://${cleanAppName}-preview-${appId}.byop.local`;
  };

  if (isLoading) {
    return <Spin indicator={<LoadingOutlined style={{ fontSize: 14 }} spin />} />;
  }

  if (!previewData) {
    return <span style={{ color: '#999', fontSize: '12px' }}>No preview</span>;
  }

  const canOpenPreview = previewData.status === 'running' && previewData.url;

  return (
    <div style={{ display: 'flex', alignItems: 'center', gap: '8px' }}>
      <PreviewStatusBadge 
        status={previewData.status} 
        errorMessage={previewData.error_message}
        size="small"
      />
      {canOpenPreview && (
        <Tooltip title="Open Preview">
          <Button 
            type="link" 
            size="small"
            icon={<LinkOutlined />}
            onClick={() => window.open(generatePreviewUrl(), '_blank')}
            style={{ padding: 0, minWidth: 'auto' }}
          />
        </Tooltip>
      )}
    </div>
  );
};
