import React from 'react';
import { Tag, Tooltip } from 'antd';
import { 
  ExclamationCircleOutlined, 
  CheckCircleOutlined, 
  LoadingOutlined,
  RocketOutlined,
  CloseCircleOutlined
} from '@ant-design/icons';
import { ComponentStatus } from '../types/component';

interface ComponentStatusBadgeProps {
  status: ComponentStatus;
  errorMessage?: string;
  size?: 'default' | 'small';
}

export const ComponentStatusBadge: React.FC<ComponentStatusBadgeProps> = ({ 
  status, 
  errorMessage,
  size = 'default' 
}) => {
  // Handle null/undefined status
  if (!status) {
    return (
      <Tag color="default">
        NO STATUS
      </Tag>
    );
  }
  
  const getStatusConfig = () => {
    switch (status) {
      case 'validating':
        return {
          color: 'processing',
          icon: <LoadingOutlined />,
          text: 'VALIDATING',
          tooltip: 'Component is being validated (repo check, Dockerfile analysis). This may take a few minutes.'
        };
      case 'valid':
        return {
          color: 'success',
          icon: <CheckCircleOutlined />,
          text: 'VALID',
          tooltip: 'Component validation passed and is ready for builds'
        };
      case 'invalid':
        return {
          color: 'error',
          icon: <ExclamationCircleOutlined />,
          text: 'INVALID',
          tooltip: 'Component validation failed'
        };
      case 'building':
        return {
          color: 'processing',
          icon: <LoadingOutlined />,
          text: 'BUILDING',
          tooltip: 'Component is currently being built into a container image'
        };
      case 'in_progress':
        return {
          color: 'processing',
          icon: <LoadingOutlined />,
          text: 'IN PROGRESS',
          tooltip: 'Component operation is in progress'
        };
      case 'ready':
        return {
          color: 'success',
          icon: <RocketOutlined />,
          text: 'READY',
          tooltip: 'Component built successfully and ready for deployment'
        };
      case 'failed':
        return {
          color: 'error',
          icon: <CloseCircleOutlined />,
          text: 'FAILED',
          tooltip: 'Component build failed'
        };
      default:
        return {
          color: 'default',
          icon: null,
          text: 'UNKNOWN',
          tooltip: 'Unknown component status'
        };
    }
  };

  const config = getStatusConfig();

  const tooltipContent = (
    <div>
      <div style={{ fontWeight: 'bold', marginBottom: errorMessage ? 4 : 0 }}>
        {config.tooltip}
      </div>
      {errorMessage && (status === 'invalid' || status === 'failed') && (
        <div style={{ color: '#ff7875', fontSize: '12px', maxWidth: '300px' }}>
          Error: {errorMessage}
        </div>
      )}
    </div>
  );

  return (
    <Tooltip title={tooltipContent} placement="top">
      <Tag 
        color={config.color} 
        icon={config.icon}
        style={{ fontSize: size === 'small' ? '11px' : undefined }}
      >
        {config.text}
      </Tag>
    </Tooltip>
  );
};

// Keep the old name for backward compatibility
export const ValidationStatusBadge = ComponentStatusBadge;
