import type { RefineThemedLayoutV2HeaderProps } from "@refinedev/antd";
import { useGetIdentity, useLogout } from "@refinedev/core";
import {
  Layout as AntdLayout,
  Avatar,
  Space,
  Switch,
  theme,
  Typography,
  Button,
  Badge,
  Dropdown,
  MenuProps,
  Tooltip
} from "antd";
import React, { useContext, useState, useEffect } from "react";
import { useNavigate } from "react-router";
import { ColorModeContext } from "../../contexts/color-mode";
import { 
  BellOutlined, 
  QuestionCircleOutlined,
  SettingOutlined,
  UserOutlined,
  LogoutOutlined,
  RocketOutlined
} from "@ant-design/icons";

const { Text, Title } = Typography;
const { useToken } = theme;

type IUser = {
  id: number;
  name: string;
  avatar: string;
  role?: string;
};

export const Header: React.FC<RefineThemedLayoutV2HeaderProps> = ({
  sticky = true,
}) => {
  const { token } = useToken();
  const { data: user } = useGetIdentity<IUser>();
  const { mode, setMode } = useContext(ColorModeContext);
  const [isMobile, setIsMobile] = useState(false);
  const navigate = useNavigate();
  const { mutate: logout } = useLogout();

  useEffect(() => {
    const checkScreenSize = () => {
      setIsMobile(window.innerWidth <= 768);
    };
    
    checkScreenSize();
    window.addEventListener('resize', checkScreenSize);
    
    return () => window.removeEventListener('resize', checkScreenSize);
  }, []);

  const headerStyles: React.CSSProperties = {
    backgroundColor: token.colorBgElevated,
    display: "flex",
    justifyContent: "space-between",
    alignItems: "center",
    padding: isMobile ? "0px 12px" : "0px 16px",
    height: "64px",
    boxShadow: "0 2px 4px rgba(0,0,0,0.08)",
  };

  if (sticky) {
    headerStyles.position = "sticky";
    headerStyles.top = 0;
    headerStyles.zIndex = 1;
  }
  
  const handleMenuClick = (key: string) => {
    switch (key) {
      case 'profile':
        // Navigate to profile page (you can create this route later)
        navigate('/profile');
        break;
      case 'settings':
        // Navigate to settings page (you can create this route later)
        navigate('/settings');
        break;
      case 'logout':
        // Handle logout using Refine's logout
        logout();
        break;
      default:
        break;
    }
  };

  const userMenuItems: MenuProps["items"] = [
    {
      key: "profile",
      icon: <UserOutlined />,
      label: "Profile",
      onClick: () => handleMenuClick('profile'),
    },
    {
      key: "settings",
      icon: <SettingOutlined />,
      label: "Settings", 
      onClick: () => handleMenuClick('settings'),
    },
    {
      type: "divider",
    },
    {
      key: "logout",
      icon: <LogoutOutlined />,
      label: "Logout",
      danger: true,
      onClick: () => handleMenuClick('logout'),
    },
  ];
  
  const handleNotificationClick = (key: string) => {
    if (key === 'view-all') {
      // Navigate to notifications page (you can create this route later)
      navigate('/notifications');
    } else {
      // Handle specific notification click - could navigate to deployment details
      console.log('Notification clicked:', key);
    }
  };
  
  const notificationItems: MenuProps["items"] = [
    {
      key: "1",
      label: (
        <div>
          <Text strong>New client deployment</Text>
          <div>Acme Corp SAAS deployment is now active</div>
          <Text type="secondary" style={{ fontSize: '12px' }}>5 minutes ago</Text>
        </div>
      ),
      onClick: () => handleNotificationClick('1'),
    },
    {
      key: "2",
      label: (
        <div>
          <Text strong>Alert: High CPU Usage</Text>
          <div>Client XYZ experiencing high resource utilization</div>
          <Text type="secondary" style={{ fontSize: '12px' }}>20 minutes ago</Text>
        </div>
      ),
      onClick: () => handleNotificationClick('2'),
    },
    {
      type: "divider",
    },
    {
      key: "view-all",
      label: "View all notifications",
      onClick: () => handleNotificationClick('view-all'),
    },
  ];

  return (
    <AntdLayout.Header style={headerStyles}>
      <div style={{ 
        display: "flex", 
        alignItems: "center", 
        minWidth: 0, 
        flex: 1,
        overflow: "hidden"
      }}>
        <RocketOutlined style={{ 
          fontSize: '24px', 
          marginRight: '8px', 
          color: token.colorPrimary, 
          flexShrink: 0 
        }} />
        <Title level={4} style={{ 
          margin: 0, 
          marginRight: isMobile ? '8px' : '16px', 
          flexShrink: 0,
          fontSize: isMobile ? '16px' : '20px'
        }}>
          BYOP
        </Title>
        {!isMobile && (
          <Text 
            type="secondary" 
            style={{ 
              whiteSpace: "nowrap",
              overflow: "hidden",
              textOverflow: "ellipsis"
            }}
          >
            SAAS Deployment Automation Platform
          </Text>
        )}
      </div>
      
      <Space size={isMobile ? 4 : "small"} style={{ flexShrink: 0 }}>
        {!isMobile && (
          <Tooltip title="Help & Resources">
            <Button
              type="text"
              size="small"
              icon={<QuestionCircleOutlined style={{ fontSize: '16px' }} />}
              onClick={() => navigate('/support')}
            />
          </Tooltip>
        )}
        
        <Dropdown
          menu={{ items: notificationItems }}
          placement="bottomRight"
          arrow
        >
          <Badge count={2} size="small">
            <Button
              type="text" 
              size="small"
              icon={<BellOutlined style={{ fontSize: '16px' }} />}
            />
          </Badge>
        </Dropdown>
        
        <Switch
          size="small"
          checkedChildren="🌛"
          unCheckedChildren="🔆"
          onChange={() => setMode(mode === "light" ? "dark" : "light")}
          defaultChecked={mode === "dark"}
        />
        
        <Dropdown menu={{ items: userMenuItems }} placement="bottomRight">
          <Space style={{ 
            marginLeft: isMobile ? "4px" : "8px", 
            cursor: "pointer" 
          }} size="small">
            {user?.name && !isMobile && (
              <div style={{ textAlign: "right" }}>
                <Text strong style={{ fontSize: "14px" }}>{user.name}</Text>
                {user?.role && (
                  <div>
                    <Text type="secondary" style={{ fontSize: "12px" }}>
                      {user.role}
                    </Text>
                  </div>
                )}
              </div>
            )}
            {user?.avatar ? (
              <Avatar size="small" src={user?.avatar} alt={user?.name} />
            ) : (
              <Avatar size="small" icon={<UserOutlined />} />
            )}
          </Space>
        </Dropdown>
      </Space>
    </AntdLayout.Header>
  );
};
