import dataProvider from "@refinedev/simple-rest";
import { DataProvider } from "@refinedev/core";
import { TOKEN_KEY } from "../authProvider";

/**
 * Custom data provider that uses PUT instead of PATCH for updates
 * to comply with the BYOP API specifications
 */
export const customDataProvider = (apiUrl: string): DataProvider => {
  const baseDataProvider = dataProvider(apiUrl);

  // Helper function to get auth headers
  const getAuthHeaders = () => {
    const token = localStorage.getItem(TOKEN_KEY);
    return token ? { Authorization: `Bearer ${token}` } : {};
  };

  return {
    ...baseDataProvider,
    update: async ({ resource, id, variables, meta }) => {
      const url = `${apiUrl}/${resource}/${id}`;

      const response = await fetch(url, {
        method: "PUT", // Use PUT instead of PATCH
        headers: {
          "Content-Type": "application/json",
          ...getAuthHeaders(),
          ...meta?.headers,
        },
        body: JSON.stringify(variables),
      });

      if (!response.ok) {
        const errorText = await response.text();
        let errorMessage;
        
        try {
          const errorJson = JSON.parse(errorText);
          errorMessage = errorJson.message || errorJson.error || errorText;
        } catch {
          errorMessage = errorText;
        }
        
        throw new Error(errorMessage);
      }

      const data = await response.json();

      return {
        data,
      };
    },

    // Override other methods to ensure consistent auth header handling
    create: async ({ resource, variables, meta }) => {
      const url = `${apiUrl}/${resource}`;

      const response = await fetch(url, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
          ...getAuthHeaders(),
          ...meta?.headers,
        },
        body: JSON.stringify(variables),
      });

      if (!response.ok) {
        const errorText = await response.text();
        let errorMessage;
        
        try {
          const errorJson = JSON.parse(errorText);
          errorMessage = errorJson.message || errorJson.error || errorText;
        } catch {
          errorMessage = errorText;
        }
        
        throw new Error(errorMessage);
      }

      const data = await response.json();

      return {
        data,
      };
    },

    deleteOne: async ({ resource, id, meta }) => {
      const url = `${apiUrl}/${resource}/${id}`;

      const response = await fetch(url, {
        method: "DELETE",
        headers: {
          ...getAuthHeaders(),
          ...meta?.headers,
        },
      });

      if (!response.ok) {
        const errorText = await response.text();
        let errorMessage;
        
        try {
          const errorJson = JSON.parse(errorText);
          errorMessage = errorJson.message || errorJson.error || errorText;
        } catch {
          errorMessage = errorText;
        }
        
        throw new Error(errorMessage);
      }

      // Try to parse response, fallback to empty object if no content
      let data;
      try {
        const responseText = await response.text();
        data = responseText ? JSON.parse(responseText) : { id };
      } catch {
        data = { id };
      }

      return {
        data,
      };
    },

    getOne: async ({ resource, id, meta }) => {
      const url = `${apiUrl}/${resource}/${id}`;

      const response = await fetch(url, {
        headers: {
          ...getAuthHeaders(),
          ...meta?.headers,
        },
      });

      if (!response.ok) {
        const errorText = await response.text();
        let errorMessage;
        
        try {
          const errorJson = JSON.parse(errorText);
          errorMessage = errorJson.message || errorJson.error || errorText;
        } catch {
          errorMessage = errorText;
        }
        
        throw new Error(errorMessage);
      }

      const data = await response.json();

      return {
        data,
      };
    },

    getList: async ({ resource, pagination, filters, sorters, meta }) => {
      const url = new URL(`${apiUrl}/${resource}`);

      // Handle pagination
      if (pagination) {
        if (pagination.current) {
          url.searchParams.append("_page", pagination.current.toString());
        }
        if (pagination.pageSize) {
          url.searchParams.append("_limit", pagination.pageSize.toString());
        }
      }

      // Handle filters
      if (filters) {
        filters.forEach((filter) => {
          if (filter.operator === "eq") {
            url.searchParams.append(filter.field, filter.value);
          }
        });
      }

      // Handle sorting
      if (sorters) {
        sorters.forEach((sorter) => {
          url.searchParams.append("_sort", sorter.field);
          url.searchParams.append("_order", sorter.order);
        });
      }

      const response = await fetch(url.toString(), {
        headers: {
          ...getAuthHeaders(),
          ...meta?.headers,
        },
      });

      if (!response.ok) {
        const errorText = await response.text();
        let errorMessage;
        
        try {
          const errorJson = JSON.parse(errorText);
          errorMessage = errorJson.message || errorJson.error || errorText;
        } catch {
          errorMessage = errorText;
        }
        
        throw new Error(errorMessage);
      }

      const data = await response.json();

      return {
        data: Array.isArray(data) ? data : [data],
        total: Array.isArray(data) ? data.length : 1,
      };
    },
  };
};
