import React from 'react';
import { Show } from "@refinedev/antd";
import { useShow, useMany } from "@refinedev/core";
import { Card, Descriptions, Tag, Typography, Table, Button, Space, Row, Col } from 'antd';
import { RefreshButton, DateField, ShowButton } from '@refinedev/antd';
import { ApiOutlined, EyeOutlined } from '@ant-design/icons';
import { PreviewControl, ComponentStatusDisplay } from '../../components';

const { Title } = Typography;

export const AppShow = () => {
    const { queryResult } = useShow();
    const { data, isLoading } = queryResult;
    const record = data?.data;

    // Fetch component details for all component IDs
    // Note: Backend useMany API seems to ignore ID filtering, so we'll filter client-side
    const { data: componentsData, isLoading: componentsLoading } = useMany({
        resource: "components",
        ids: record?.components || [],
        queryOptions: {
            enabled: !!record?.components?.length,
        },
    });

    // Client-side filtering as workaround for backend API issue
    // Backend returns all components instead of filtering by IDs
    const appComponents = componentsData?.data?.filter((component: any) => 
        record?.components?.includes(component.id)
    ) || [];

    return (
        <Show
            isLoading={isLoading}
            headerButtons={[
                <Button
                    key="deploy"
                    type="primary"
                    icon={<ApiOutlined />}
                    href={`/deployments/create?appId=${record?.id}`}
                >
                    Deploy
                </Button>,
                <RefreshButton key="refresh" />
            ]}
        >
            <Title level={4}>App Details</Title>
            
            <Row gutter={[16, 16]}>
                <Col span={12}>
                    <Card style={{ height: '100%' }}>
                        <Descriptions column={1} bordered>
                            <Descriptions.Item label="Name">
                                {record?.name}
                            </Descriptions.Item>
                            
                            <Descriptions.Item label="Version">
                                <Tag color="blue">{record?.version}</Tag>
                            </Descriptions.Item>
                            
                            <Descriptions.Item label="Components Count">
                                <Tag color="green">{record?.components?.length || 0} Components</Tag>
                            </Descriptions.Item>
                            
                            <Descriptions.Item label="Created">
                                <DateField value={record?.createdAt} />
                            </Descriptions.Item>
                            
                            <Descriptions.Item label="Updated">
                                <DateField value={record?.updatedAt} />
                            </Descriptions.Item>
                        </Descriptions>
                    </Card>
                </Col>
                
                <Col span={12}>
                    {record?.id && record?.name && (
                        <PreviewControl 
                            appId={Number(record.id)} 
                            appName={record.name}
                        />
                    )}
                </Col>
            </Row>

            <Card title="Components" style={{ marginTop: 16 }}>
                {componentsLoading ? (
                    <div>Loading components...</div>
                ) : appComponents.length > 0 ? (
                    <Table
                        dataSource={appComponents}
                        rowKey="id"
                        pagination={false}
                    >
                        <Table.Column dataIndex="name" title="Name" />
                        <Table.Column dataIndex="version" title="Version" 
                            render={(value) => <Tag color="blue">{value}</Tag>}
                        />
                        <Table.Column 
                            dataIndex="type" 
                            title="Type"
                            render={(value) => {
                                const colorMap: Record<string, string> = {
                                    frontend: 'blue',
                                    backend: 'green',
                                    api: 'purple',
                                    database: 'orange',
                                    microservice: 'cyan',
                                };
                                return (
                                    <Tag color={colorMap[value] || 'default'}>
                                        {value?.toUpperCase()}
                                    </Tag>
                                );
                            }}
                        />
                        <Table.Column 
                            title="Status"
                            render={(_, record) => (
                                <ComponentStatusDisplay 
                                    componentId={record.id} 
                                    size="small"
                                />
                            )}
                        />
                        <Table.Column
                            title="Actions"
                            render={(_, record) => (
                                <Space>
                                    <ShowButton hideText size="small" recordItemId={record.id} resource="components" />
                                </Space>
                            )}
                        />
                    </Table>
                ) : (
                    <div style={{ textAlign: 'center', color: '#999', padding: '20px' }}>
                        No components found
                    </div>
                )}
            </Card>
        </Show>
    );
};
