import {
  DeleteButton,
  EditButton,
  List,
  ShowButton,
  useTable,
} from "@refinedev/antd";
import type { BaseRecord } from "@refinedev/core";
import { Space, Table, Tag, Button, Typography } from "antd";
import { PlusOutlined } from "@ant-design/icons";
import { ComponentStatusBadge } from "../../components";
import { useEffect } from "react";
import { shouldPollComponentStatus } from "../../utils/componentPolling";

const { Title } = Typography;

export const ComponentList = () => {
  const { tableProps, tableQueryResult } = useTable({
    syncWithLocation: true,
  });

  // Auto-refresh for components that are validating or building
  useEffect(() => {
    const hasActiveComponents = tableQueryResult?.data?.data?.some((component: any) => 
      shouldPollComponentStatus(component.status)
    );

    if (hasActiveComponents) {
      const interval = setInterval(() => {
        tableQueryResult?.refetch();
      }, 3000); // Poll every 3 seconds

      return () => clearInterval(interval);
    }
  }, [tableQueryResult?.data?.data, tableQueryResult]);

  return (
    <>
      <div style={{ display: "flex", justifyContent: "space-between", alignItems: "center", marginBottom: 16 }}>
        <Title level={4}>Components</Title>
        <Button type="primary" icon={<PlusOutlined />} href="/components/create">
          Create New Component
        </Button>
      </div>

      <List>
        <Table {...tableProps} rowKey="id">
          <Table.Column dataIndex="name" title="Name" />
          <Table.Column dataIndex="description" title="Description" />
          <Table.Column 
            dataIndex="type" 
            title="Type" 
            render={(value) => {
              const colorMap: Record<string, string> = {
                frontend: 'blue',
                backend: 'green',
                api: 'purple',
                database: 'orange',
                microservice: 'cyan',
              };
              
              return (
                <Tag color={colorMap[value] || 'default'}>
                  {value?.toUpperCase()}
                </Tag>
              );
            }}
          />
          <Table.Column 
            dataIndex="status" 
            title="Status"
            render={(value, record: any) => {
              return (
                <ComponentStatusBadge 
                  status={value}
                  errorMessage={record.error_msg}
                  size="small"
                />
              );
            }}
          />
          <Table.Column 
            dataIndex="current_image_tag" 
            title="Current Image"
            render={(value, record: any) => (
              value ? (
                <div>
                  <Tag color="green">{value}</Tag>
                  {record.status === 'ready' && (
                    <div style={{ fontSize: '11px', color: '#999', marginTop: '2px' }}>
                      Ready for deployment
                    </div>
                  )}
                </div>
              ) : (
                <span style={{ color: '#999', fontSize: '12px' }}>
                  {record.status === 'valid' ? 'Not built' : 'No image'}
                </span>
              )
            )}
          />
          <Table.Column 
            dataIndex="repository" 
            title="Repository"
            render={(value) => (
              value ? (
                <a href={value} target="_blank" rel="noopener noreferrer">
                  {value.replace(/^https?:\/\//, '').substring(0, 30)}...
                </a>
              ) : (
                <span style={{ color: '#999' }}>No Repository</span>
              )
            )}
          />
          <Table.Column 
            dataIndex="branch" 
            title="Branch"
            render={(value) => (
              value ? (
                <Tag color="blue">{value}</Tag>
              ) : (
                <Tag color="default">main</Tag>
              )
            )}
          />
          <Table.Column
            title="Actions"
            dataIndex="actions"
            render={(_, record: BaseRecord) => (
              <Space>
                <ShowButton hideText size="small" recordItemId={record.id} />
                <EditButton hideText size="small" recordItemId={record.id} />
                <DeleteButton hideText size="small" recordItemId={record.id} />
              </Space>
            )}
          />
        </Table>
      </List>
    </>
  );
};
