import React from 'react';
import { Show } from "@refinedev/antd";
import { useShow } from "@refinedev/core";
import { Card, Descriptions, Tag, Typography, Button, Alert } from 'antd';
import { RefreshButton, DateField } from '@refinedev/antd';
import { LinkOutlined, EyeOutlined, RocketOutlined } from '@ant-design/icons';
import { ComponentStatusBadge } from "../../components";
import { useComponentStatusPolling } from "../../hooks/useComponentStatusPolling";

const { Title, Text } = Typography;

export const ComponentShow = () => {
  const { queryResult } = useShow();
  const { data, isLoading } = queryResult;
  const record = data?.data;
  const { isPolling } = useComponentStatusPolling(queryResult);

  const getTypeColor = (type: string) => {
    const colorMap: Record<string, string> = {
      frontend: 'blue',
      backend: 'green',
      api: 'purple',
      database: 'orange',
      microservice: 'cyan',
    };
    return colorMap[type] || 'default';
  };

  const renderBuildButton = () => {
    if (record?.status === 'valid' || record?.status === 'ready') {
      return (
        <Button 
          key="build"
          type="primary" 
          icon={<RocketOutlined />}
          // This would trigger a build - implement based on your API
          onClick={() => {
            // TODO: Implement build trigger
            console.log('Trigger build for component:', record.id);
          }}
        >
          Build Component
        </Button>
      );
    }
    return null;
  };

  const renderDeploymentsButton = () => {
    return (
      <Button 
        key="deployments"
        icon={<EyeOutlined />}
        href={`/components/${record?.id}/deployments`}
      >
        View Deployments
      </Button>
    );
  };

  return (
    <Show
      isLoading={isLoading}
      headerButtons={[
        renderBuildButton(),
        renderDeploymentsButton(),
        <RefreshButton key="refresh" />
      ].filter(Boolean)}
    >
      <Title level={4}>Component Details</Title>

      {/* Status Alert for async operations */}
      {(record?.status === 'validating' || record?.status === 'building' || record?.status === 'in_progress') && (
        <Alert
          message={
            record.status === 'validating' 
              ? "Component Validation in Progress"
              : record.status === 'in_progress'
              ? "Component Operation in Progress" 
              : "Component Build in Progress"
          }
          description={
            record.status === 'validating' 
              ? "The system is validating your repository and analyzing the Dockerfile. This may take a few minutes."
              : record.status === 'in_progress'
              ? "The component operation is in progress. This may take a few minutes."
              : "Your component is being built into a container image. This may take several minutes depending on the complexity."
          }
          type="info"
          showIcon
          style={{ marginBottom: 16 }}
        />
      )}

      {/* Error Alert */}
      {(record?.status === 'invalid' || record?.status === 'failed') && record?.error_msg && (
        <Alert
          message={record.status === 'invalid' ? "Validation Failed" : "Build Failed"}
          description={record.error_msg}
          type="error"
          showIcon
          style={{ marginBottom: 16 }}
        />
      )}

      <Card>
        <Descriptions column={2} bordered>
          <Descriptions.Item label="Name" span={2}>
            {record?.name}
          </Descriptions.Item>
          
          <Descriptions.Item label="Description" span={2}>
            {record?.description || <span style={{ color: '#999' }}>No description</span>}
          </Descriptions.Item>
          
          <Descriptions.Item label="Type">
            <Tag color={getTypeColor(record?.type)}>
              {record?.type?.toUpperCase()}
            </Tag>
          </Descriptions.Item>

          <Descriptions.Item label="Status">
            <ComponentStatusBadge 
              status={record?.status}
              errorMessage={record?.error_msg}
            />
          </Descriptions.Item>

          {/* Image Information */}
          {record?.current_image_tag && (
            <>
              <Descriptions.Item label="Current Image Tag">
                <Tag color="green">{record.current_image_tag}</Tag>
              </Descriptions.Item>
              <Descriptions.Item label="Image URI">
                <Text code copyable style={{ fontSize: '12px' }}>
                  {record.current_image_uri}
                </Text>
              </Descriptions.Item>
            </>
          )}

          <Descriptions.Item label="Configuration" span={2}>
            <pre style={{ background: '#f5f5f5', padding: '8px', borderRadius: '4px', overflow: 'auto' }}>
              {record?.config || '{}'}
            </pre>
          </Descriptions.Item>
          
          <Descriptions.Item label="Git Repository" span={2}>
            {record?.repository ? (
              <a 
                href={record.repository} 
                target="_blank" 
                rel="noopener noreferrer"
                style={{ display: 'flex', alignItems: 'center', gap: '8px' }}
              >
                <LinkOutlined />
                {record.repository}
              </a>
            ) : (
              <span style={{ color: '#999' }}>No repository URL</span>
            )}
          </Descriptions.Item>

          <Descriptions.Item label="Branch">
            <Tag color="blue">
              {record?.branch || 'main'}
            </Tag>
          </Descriptions.Item>

          <Descriptions.Item label="Created">
            <DateField value={record?.created_at} />
          </Descriptions.Item>
          
          <Descriptions.Item label="Updated">
            <DateField value={record?.updated_at} />
          </Descriptions.Item>
        </Descriptions>
      </Card>
    </Show>
  );
};
