import { useList } from "@refinedev/core";
import { useNavigate } from "react-router";
import { 
  Card, 
  Row, 
  Col, 
  Typography, 
  Space,
  Button,
  Tag,
  Avatar,
  List as AntList,
  Spin
} from "antd";
import {
  RocketOutlined,
  UserOutlined,
  AppstoreOutlined,
  PlusOutlined,
  ThunderboltOutlined,
  CloudOutlined,
  EyeOutlined
} from "@ant-design/icons";

const { Title, Text, Paragraph } = Typography;

export const DashboardOverview = () => {
  const navigate = useNavigate();
  
  // Fetch data from API
  const { data: deploymentsData, isLoading: deploymentsLoading } = useList({
    resource: "deployments",
  });

  const { data: clientsData, isLoading: clientsLoading } = useList({
    resource: "clients",
  });

  const { data: componentsData, isLoading: componentsLoading } = useList({
    resource: "components",
  });

  const { data: appsData, isLoading: appsLoading } = useList({
    resource: "apps",
  });

  // Show loading spinner if any data is loading
  if (deploymentsLoading || clientsLoading || componentsLoading || appsLoading) {
    return (
      <div style={{ 
        display: 'flex', 
        justifyContent: 'center', 
        alignItems: 'center', 
        height: '50vh' 
      }}>
        <Spin size="large" />
      </div>
    );
  }
  
  // Calculate statistics
  const totalDeployments = deploymentsData?.data?.length || 0;
  const activeDeployments = deploymentsData?.data?.filter((item: any) => item.status === "active")?.length || 0;
  const totalClients = clientsData?.data?.length || 0;
  const totalComponents = componentsData?.data?.length || 0;
  const totalApps = appsData?.data?.length || 0;
  
  // Recent activity items
  const recentDeployments = deploymentsData?.data?.slice(0, 5) || [];

  return (
    <div style={{ padding: '0 8px' }}>
      {/* Header */}
      <div style={{ 
        display: "flex", 
        justifyContent: "space-between", 
        alignItems: "center", 
        marginBottom: 24,
        padding: '16px 0 0 0'
      }}>
        <div>
          <Title level={2} style={{ margin: 0, color: '#1a1a1a' }}>
            Dashboard
          </Title>
          <Text type="secondary" style={{ fontSize: 15 }}>
            Overview of your deployments and resources
          </Text>
        </div>
        <Space>
          <Button 
            icon={<PlusOutlined />} 
            type="primary"
            onClick={() => navigate("/setup")}
            style={{ 
              borderRadius: 6,
              height: 36
            }}
          >
            New Deployment
          </Button>
        </Space>
      </div>

      {/* Welcome Card for New Users */}
      {totalDeployments === 0 && (
        <Card 
          style={{ 
            background: "linear-gradient(135deg, #1890ff 0%, #722ed1 100%)",
            border: 'none',
            borderRadius: 12,
            marginBottom: 24,
            textAlign: "center"
          }}
          bodyStyle={{ padding: '40px 24px' }}
        >
          <Space direction="vertical" size="middle" style={{ width: "100%" }}>
            <RocketOutlined style={{ fontSize: 48, color: "white" }} />
            <div>
              <Title level={3} style={{ color: "white", margin: 0 }}>
                Welcome to BYOP!
              </Title>
              <Text style={{ 
                color: "rgba(255,255,255,0.9)", 
                fontSize: 16, 
                marginTop: 12,
                display: 'block'
              }}>
                Get started by creating your first deployment
              </Text>
            </div>
            <Button 
              size="large" 
              icon={<PlusOutlined />}
              onClick={() => navigate("/setup")}
              style={{ 
                backgroundColor: "rgba(255,255,255,0.15)", 
                borderColor: "rgba(255,255,255,0.3)",
                color: "white",
                height: 40,
                borderRadius: 6
              }}
            >
              Create Deployment
            </Button>
          </Space>
        </Card>
      )}

      {/* Statistics Cards */}
      <Row gutter={[20, 20]} style={{ marginBottom: 24 }}>
        <Col xs={24} sm={12} lg={6}>
          <Card 
            style={{ 
              borderRadius: 8, 
              border: '1px solid #f0f0f0',
              boxShadow: '0 1px 4px rgba(0,0,0,0.04)'
            }}
            bodyStyle={{ padding: '20px' }}
          >
            <div style={{ display: 'flex', alignItems: 'center', justifyContent: 'space-between' }}>
              <div>
                <Text type="secondary" style={{ fontSize: 13, fontWeight: 500 }}>
                  Deployments
                </Text>
                <div style={{ marginTop: 4 }}>
                  <Text style={{ fontSize: 28, fontWeight: 600, color: '#1890ff' }}>
                    {totalDeployments}
                  </Text>
                </div>
                <div style={{ marginTop: 2 }}>
                  <Text type="secondary" style={{ fontSize: 11 }}>
                    {activeDeployments} active
                  </Text>
                </div>
              </div>
              <Avatar 
                size={40} 
                style={{ backgroundColor: '#e6f7ff', color: '#1890ff' }}
                icon={<RocketOutlined />}
              />
            </div>
          </Card>
        </Col>
        
        <Col xs={24} sm={12} lg={6}>
          <Card 
            style={{ 
              borderRadius: 8, 
              border: '1px solid #f0f0f0',
              boxShadow: '0 1px 4px rgba(0,0,0,0.04)'
            }}
            bodyStyle={{ padding: '20px' }}
          >
            <div style={{ display: 'flex', alignItems: 'center', justifyContent: 'space-between' }}>
              <div>
                <Text type="secondary" style={{ fontSize: 13, fontWeight: 500 }}>
                  Clients
                </Text>
                <div style={{ marginTop: 4 }}>
                  <Text style={{ fontSize: 28, fontWeight: 600, color: '#52c41a' }}>
                    {totalClients}
                  </Text>
                </div>
                <div style={{ marginTop: 2 }}>
                  <Text type="secondary" style={{ fontSize: 11 }}>
                    Organizations
                  </Text>
                </div>
              </div>
              <Avatar 
                size={40} 
                style={{ backgroundColor: '#f6ffed', color: '#52c41a' }}
                icon={<UserOutlined />}
              />
            </div>
          </Card>
        </Col>

        <Col xs={24} sm={12} lg={6}>
          <Card 
            style={{ 
              borderRadius: 8, 
              border: '1px solid #f0f0f0',
              boxShadow: '0 1px 4px rgba(0,0,0,0.04)'
            }}
            bodyStyle={{ padding: '20px' }}
          >
            <div style={{ display: 'flex', alignItems: 'center', justifyContent: 'space-between' }}>
              <div>
                <Text type="secondary" style={{ fontSize: 13, fontWeight: 500 }}>
                  Components
                </Text>
                <div style={{ marginTop: 4 }}>
                  <Text style={{ fontSize: 28, fontWeight: 600, color: '#722ed1' }}>
                    {totalComponents}
                  </Text>
                </div>
                <div style={{ marginTop: 2 }}>
                  <Text type="secondary" style={{ fontSize: 11 }}>
                    Available
                  </Text>
                </div>
              </div>
              <Avatar 
                size={40} 
                style={{ backgroundColor: '#f9f0ff', color: '#722ed1' }}
                icon={<AppstoreOutlined />}
              />
            </div>
          </Card>
        </Col>

        <Col xs={24} sm={12} lg={6}>
          <Card 
            style={{ 
              borderRadius: 8, 
              border: '1px solid #f0f0f0',
              boxShadow: '0 1px 4px rgba(0,0,0,0.04)'
            }}
            bodyStyle={{ padding: '20px' }}
          >
            <div style={{ display: 'flex', alignItems: 'center', justifyContent: 'space-between' }}>
              <div>
                <Text type="secondary" style={{ fontSize: 13, fontWeight: 500 }}>
                  Applications
                </Text>
                <div style={{ marginTop: 4 }}>
                  <Text style={{ fontSize: 28, fontWeight: 600, color: '#fa8c16' }}>
                    {totalApps}
                  </Text>
                </div>
                <div style={{ marginTop: 2 }}>
                  <Text type="secondary" style={{ fontSize: 11 }}>
                    Ready
                  </Text>
                </div>
              </div>
              <Avatar 
                size={40} 
                style={{ backgroundColor: '#fff7e6', color: '#fa8c16' }}
                icon={<CloudOutlined />}
              />
            </div>
          </Card>
        </Col>
      </Row>

      {/* Quick Actions & Recent Activity */}
      <Row gutter={[20, 20]}>
        <Col xs={24} lg={12}>
          <Card 
            title={<Text strong style={{ fontSize: 15 }}>Quick Actions</Text>}
            style={{ 
              borderRadius: 8, 
              border: '1px solid #f0f0f0',
              boxShadow: '0 1px 4px rgba(0,0,0,0.04)'
            }}
            bodyStyle={{ padding: '20px' }}
          >
            <Space direction="vertical" size="small" style={{ width: '100%' }}>
              <Button 
                block 
                size="middle"
                icon={<PlusOutlined />}
                onClick={() => navigate("/setup")}
                style={{ height: 40, borderRadius: 6 }}
              >
                Create Deployment
              </Button>
              <Button 
                block 
                size="middle"
                icon={<AppstoreOutlined />}
                onClick={() => navigate("/components/create")}
                style={{ height: 40, borderRadius: 6 }}
              >
                Add Component
              </Button>
              <Button 
                block 
                size="middle"
                icon={<UserOutlined />}
                onClick={() => navigate("/clients/create")}
                style={{ height: 40, borderRadius: 6 }}
              >
                Register Client
              </Button>
            </Space>
          </Card>
        </Col>

        <Col xs={24} lg={12}>
          <Card 
            title={
              <div style={{ display: 'flex', alignItems: 'center', justifyContent: 'space-between' }}>
                <Text strong style={{ fontSize: 15 }}>Recent Deployments</Text>
                <Button 
                  type="link" 
                  size="small"
                  icon={<EyeOutlined />}
                  onClick={() => navigate("/deployments")}
                  style={{ padding: '4px 8px' }}
                >
                  View All
                </Button>
              </div>
            }
            style={{ 
              borderRadius: 8, 
              border: '1px solid #f0f0f0',
              boxShadow: '0 1px 4px rgba(0,0,0,0.04)'
            }}
            bodyStyle={{ padding: '20px' }}
          >
            {recentDeployments.length > 0 ? (
              <AntList
                dataSource={recentDeployments}
                renderItem={(item: any) => (
                  <AntList.Item style={{ padding: '8px 0', border: 'none' }}>
                    <AntList.Item.Meta
                      avatar={
                        <Avatar 
                          size={32} 
                          style={{ backgroundColor: '#1890ff' }}
                          icon={<RocketOutlined />}
                        />
                      }
                      title={
                        <Text strong style={{ fontSize: 13 }}>
                          {item.name || `Deployment ${item.id}`}
                        </Text>
                      }
                      description={
                        <div style={{ display: 'flex', alignItems: 'center', gap: 6 }}>
                          <Tag 
                            color={item.environment === 'prod' ? 'red' : item.environment === 'preprod' ? 'orange' : 'green'}
                            style={{ margin: 0, fontSize: 11 }}
                          >
                            {item.environment?.toUpperCase()}
                          </Tag>
                          <Text type="secondary" style={{ fontSize: 11 }}>
                            v{item.version}
                          </Text>
                        </div>
                      }
                    />
                  </AntList.Item>
                )}
              />
            ) : (
              <div style={{ textAlign: 'center', padding: '30px 16px' }}>
                <Text type="secondary" style={{ fontSize: 13 }}>No deployments yet</Text>
                <div style={{ marginTop: 6 }}>
                  <Button 
                    type="link" 
                    size="small"
                    onClick={() => navigate("/setup")}
                  >
                    Create your first deployment
                  </Button>
                </div>
              </div>
            )}
          </Card>
        </Col>
      </Row>
    </div>
  );
};