import { Create, useForm, useSelect } from "@refinedev/antd";
import { Form, Input, Select, Card } from "antd";
import { DeploymentFormData } from "../../types/deployment";
import { useEffect } from "react";

export const DeploymentCreate = () => {
  const { formProps, saveButtonProps, form } = useForm<DeploymentFormData>({});

  const { selectProps: clientSelectProps, queryResult: clientQuery } = useSelect({
    resource: "clients",
    optionLabel: "name",
    optionValue: "id",
  });

  const { selectProps: appSelectProps, queryResult: appQuery } = useSelect({
    resource: "apps",
    optionLabel: "name", 
    optionValue: "id",
  });

  // Function to generate deployment name
  const generateDeploymentName = () => {
    const formValues = form.getFieldsValue();
    const { environment, app_id, version, client_id } = formValues as DeploymentFormData;
    
    if (!environment || !app_id || !version || !client_id) return '';

    const appName = appQuery.data?.data?.find((app: any) => app.id === app_id)?.name || 'app';
    const clientName = clientQuery.data?.data?.find((client: any) => client.id === client_id)?.name || 'client';
    
    return `${environment}-${appName}-${version}-${clientName}`;
  };

  // Auto-generate name when other fields change
  useEffect(() => {
    const currentName = form.getFieldValue('name');
    if (!currentName || currentName.trim() === '') {
      const generatedName = generateDeploymentName();
      if (generatedName) {
        form.setFieldValue('name', generatedName);
      }
    }
  }, [form]);

  const handleFieldChange = () => {
    const currentName = form.getFieldValue('name');
    if (!currentName || currentName.trim() === '') {
      const generatedName = generateDeploymentName();
      if (generatedName) {
        form.setFieldValue('name', generatedName);
      }
    }
  };

  return (
    <Create saveButtonProps={saveButtonProps}>
      <Form {...formProps} layout="vertical">
        <Card title="Deployment Information">
          <Form.Item
            label="Deployment Name"
            name="name"
            rules={[{ required: true, message: 'Please enter a deployment name' }]}
            extra="Leave empty to auto-generate from environment-app-version-client"
          >
            <Input placeholder="Auto-generated if empty" />
          </Form.Item>

          <Form.Item
            label={"App"}
            name="app_id"
            rules={[{ required: true, message: 'Please select an app to deploy' }]}
          >
            <Select 
              {...appSelectProps} 
              placeholder="Select app to deploy" 
              onChange={handleFieldChange}
            />
          </Form.Item>

          <Form.Item
            label={"Environment"}
            name="environment"
            rules={[{ required: true, message: 'Please select an environment' }]}
          >
            <Select
              placeholder="Select environment"
              onChange={handleFieldChange}
              options={[
                { value: "dev", label: "Development" },
                { value: "preprod", label: "Pre-Production" },
                { value: "prod", label: "Production" },
              ]}
            />
          </Form.Item>

          <Form.Item
            label={"Version"}
            name="version"
            initialValue={"1.0.0"}
            rules={[{ required: true, message: 'Please enter a version' }]}
          >
            <Input placeholder="E.g., 1.0.0" onChange={handleFieldChange} />
          </Form.Item>

          <Form.Item
            label={"Client"}
            name="client_id"
            rules={[{ required: true, message: 'Please select a client' }]}
          >
            <Select 
              {...clientSelectProps} 
              placeholder="Select client to deploy for" 
              onChange={handleFieldChange}
            />
          </Form.Item>
        </Card>
      </Form>
    </Create>
  );
};