import { Show } from "@refinedev/antd";
import { useShow } from "@refinedev/core";
import { 
  Typography, Card, Descriptions, Tabs, Table, Tag, Badge, 
  List, Space, Divider, Button, Row, Col, Tooltip 
} from "antd";
import { 
  ApiOutlined, ForkOutlined, LockOutlined, 
  GlobalOutlined, RocketOutlined, CheckCircleOutlined 
} from '@ant-design/icons';

const { Title, Text } = Typography;
const { TabPane } = Tabs;

export const TemplateShow = () => {
  const { queryResult } = useShow();
  const { data, isLoading } = queryResult;
  const record = data?.data;

  // Format environment variables for display
  const formatEnvVars = (envVars: Record<string, string> = {}) => {
    return Object.entries(envVars).map(([key, value]) => ({
      key,
      value,
    }));
  };

  return (
    <Show isLoading={isLoading}
      headerButtons={
        <>
          <Button type="primary" icon={<RocketOutlined />}>Deploy with This Template</Button>
          <Button>Edit Template</Button>
        </>
      }
    >
      <Title level={4}>{record?.name}</Title>
      <Descriptions bordered column={2} style={{ marginBottom: 20 }}>
        <Descriptions.Item label="Template ID">{record?.id}</Descriptions.Item>
        <Descriptions.Item label="Version">{record?.version}</Descriptions.Item>
        <Descriptions.Item label="Created By">{record?.createdBy || 'System'}</Descriptions.Item>
        <Descriptions.Item label="Created At">{record?.createdAt}</Descriptions.Item>
        <Descriptions.Item label="Last Updated">{record?.updatedAt}</Descriptions.Item>
        <Descriptions.Item label="Active Deployments">{record?.deployments?.length || 0}</Descriptions.Item>
        <Descriptions.Item label="Description" span={2}>
          {record?.description}
        </Descriptions.Item>
      </Descriptions>

      <Tabs defaultActiveKey="apps">
        <TabPane tab={<span><ApiOutlined /> Apps Configuration</span>} key="apps">
          <Table 
            dataSource={record?.config?.apps || []}
            rowKey="id"
            pagination={false}
            expandable={{
              expandedRowRender: (app: {
                  resources: any;
                  autoscaling: any; envOverrides?: Record<string, string> 
}) => (
                <div style={{ padding: 16 }}>
                  <Title level={5}>Resource Configuration</Title>
                  <Descriptions bordered column={3} size="small">
                    <Descriptions.Item label="CPU">{app.resources.cpu}</Descriptions.Item>
                    <Descriptions.Item label="Memory">{app.resources.memory}</Descriptions.Item>
                    <Descriptions.Item label="Storage">{app.resources.storage}</Descriptions.Item>
                  </Descriptions>
                  
                  {app.autoscaling && app.autoscaling.enabled && (
                    <>
                      <Title level={5} style={{ marginTop: 16 }}>Autoscaling</Title>
                      <Descriptions bordered column={2} size="small">
                        <Descriptions.Item label="Min Replicas">{app.autoscaling.minReplicas}</Descriptions.Item>
                        <Descriptions.Item label="Max Replicas">{app.autoscaling.maxReplicas}</Descriptions.Item>
                        <Descriptions.Item label="CPU Threshold">{app.autoscaling.cpuThreshold}%</Descriptions.Item>
                        <Descriptions.Item label="Scaling Metric">{app.autoscaling.metric}</Descriptions.Item>
                      </Descriptions>
                    </>
                  )}

                  {app.envOverrides && Object.keys(app.envOverrides).length > 0 && (
                    <>
                      <Title level={5} style={{ marginTop: 16 }}>Environment Overrides</Title>
                      <Table 
                        dataSource={Object.entries(app.envOverrides || {}).map(([key, value]) => ({ key, value }))}
                        columns={[
                          { title: 'Key', dataIndex: 'key' },
                          { title: 'Value', dataIndex: 'value' }
                        ]}
                        size="small"
                        pagination={false}
                      />
                    </>
                  )}
                </div>
              )
            }}
            columns={[
              { title: 'App ID', dataIndex: 'id' },
              { title: 'Name', dataIndex: 'name' },
              { 
                title: 'Ports', 
                dataIndex: 'exposedPorts',
                render: (ports: number[]) => (
                  <Space>
                    {ports && ports.length > 0 ? ports.map((port) => (
                      <Tag key={port} color="blue">{port}</Tag>
                    )) : 'None'}
                  </Space>
                )
              },
              {
                title: 'Public Access',
                dataIndex: 'publicAccess',
                render: (value: boolean) => (
                  value ? <Badge status="success" text="Yes" /> : <Badge status="default" text="No" />
                )
              },
              {
                title: 'Service Mesh',
                dataIndex: 'serviceMesh',
                render: (value: boolean) => (
                  value ? <Badge status="success" text="Yes" /> : <Badge status="default" text="No" />
                )
              },
              {
                title: 'Autoscaling',
                dataIndex: 'autoscaling',
                render: (autoscaling: any) => (
                  autoscaling?.enabled ? 
                    <Tooltip title={`${autoscaling.minReplicas}-${autoscaling.maxReplicas} instances`}>
                      <Badge status="processing" text="Enabled" />
                    </Tooltip> : 
                    <Badge status="default" text="Disabled" />
                )
              }
            ]}
          />
        </TabPane>

        <TabPane tab={<span><ForkOutlined /> Network Policies</span>} key="network">
          {record?.config?.networkPolicies?.length > 0 ? (
            <List
              itemLayout="vertical"
              dataSource={record?.config?.networkPolicies || []}
              renderItem={(policy: { name: string; fromApps: string[]; toApps: string[]; ports?: number[]; allowEgress: boolean }) => (
                <Card title={policy.name} style={{ marginBottom: 16 }}>
                  <Row gutter={16}>
                    <Col span={8}>
                      <Title level={5}>Source Apps</Title>
                      <List
                        size="small"
                        dataSource={policy.fromApps}
                        renderItem={(appId) => {
                          const app = record?.config.apps.find((a: any) => a.id === appId);
                          return (
                            <List.Item>
                              {app ? app.name : appId}
                            </List.Item>
                          );
                        }}
                      />
                    </Col>
                    <Col span={8}>
                      <Title level={5}>Destination Apps</Title>
                      <List
                        size="small"
                        dataSource={policy.toApps}
                        renderItem={(appId) => {
                          const app = record?.config.apps.find((a: any) => a.id === appId);
                          return (
                            <List.Item>
                              {app ? app.name : appId}
                            </List.Item>
                          );
                        }}
                      />
                    </Col>
                    <Col span={8}>
                      <Title level={5}>Configuration</Title>
                      <Descriptions column={1} size="small">
                        <Descriptions.Item label="Allowed Ports">
                          {policy.ports && policy.ports.length > 0 ? 
                            policy.ports.map(port => <Tag key={port}>{port}</Tag>) : 
                            'All Ports'}
                        </Descriptions.Item>
                        <Descriptions.Item label="Egress Traffic">
                          {policy.allowEgress ? 
                            <Badge status="success" text="Allowed" /> : 
                            <Badge status="error" text="Blocked" />}
                        </Descriptions.Item>
                      </Descriptions>
                    </Col>
                  </Row>
                </Card>
              )}
            />
          ) : (
            <Card>
              <Text type="secondary">No network policies defined for this template.</Text>
            </Card>
          )}
        </TabPane>

        <TabPane tab={<span><GlobalOutlined /> Environment Variables</span>} key="env">
          {record?.config?.envVariables && Object.keys(record.config.envVariables).length > 0 ? (
            <Table 
              dataSource={formatEnvVars(record.config.envVariables)}
              columns={[
                { title: 'Key', dataIndex: 'key' },
                { title: 'Value', dataIndex: 'value' }
              ]}
              pagination={false}
              rowKey="key"
            />
          ) : (
            <Card>
              <Text type="secondary">No global environment variables defined for this template.</Text>
            </Card>
          )}
        </TabPane>

        <TabPane tab={<span><LockOutlined /> Secrets</span>} key="secrets">
          {record?.config?.secrets?.length > 0 ? (
            <Table 
              dataSource={record?.config.secrets}
              columns={[
                { title: 'Name', dataIndex: 'name' },
                { title: 'Description', dataIndex: 'description' },
                { 
                  title: 'Required', 
                  dataIndex: 'required',
                  render: (value: boolean) => value ? (
                    <CheckCircleOutlined style={{ color: '#52c41a' }} />
                  ) : (
                    <Text type="secondary">Optional</Text>
                  )
                }
              ]}
              pagination={false}
              rowKey="name"
            />
          ) : (
            <Card>
              <Text type="secondary">No secrets defined for this template.</Text>
            </Card>
          )}
        </TabPane>

        <TabPane tab="Deployments" key="deployments">
          {record?.deployments?.length > 0 ? (
            <Table
              dataSource={record?.deployments}
              columns={[
                { title: 'ID', dataIndex: 'id' },
                { title: 'Name', dataIndex: 'name' },
                { title: 'Client', dataIndex: 'clientName' },
                { 
                  title: 'Status', 
                  dataIndex: 'status',
                  render: (status) => {
                    const colorMap: Record<string, string> = {
                      active: 'green',
                      pending: 'orange',
                      failed: 'red',
                      updating: 'blue',
                      deleting: 'red'
                    };
                    
                    return <Tag color={colorMap[status] || 'default'}>{status.toUpperCase()}</Tag>;
                  }
                },
                { title: 'Created At', dataIndex: 'createdAt' }
              ]}
              pagination={false}
              rowKey="id"
            />
          ) : (
            <Card>
              <Text type="secondary">No active deployments using this template.</Text>
            </Card>
          )}
        </TabPane>
      </Tabs>
    </Show>
  );
};