import { ComponentStatus } from '../types/component';

/**
 * Determines if a component status requires polling for updates
 */
export const shouldPollComponentStatus = (status: ComponentStatus): boolean => {
  return status === 'validating' || status === 'building' || status === 'in_progress';
};

/**
 * Validates component form data according to API requirements
 */
export const validateComponentForm = (formData: any) => {
  const errors: Record<string, string> = {};
  
  if (!formData.name) {
    errors.name = 'Component name is required';
  }
  
  if (!formData.type) {
    errors.type = 'Component type is required';
  }
  
  if (!formData.repository) {
    errors.repository = 'Git repository URL is required';
  }
  
  // Validate URL format
  if (formData.repository && !isValidUrl(formData.repository)) {
    errors.repository = 'Please enter a valid Git repository URL';
  }
  
  // Validate JSON configuration if provided
  if (formData.config && formData.config.trim() !== '') {
    try {
      JSON.parse(formData.config);
    } catch (e) {
      errors.config = 'Configuration must be valid JSON';
    }
  }
  
  return errors;
};

/**
 * Simple URL validation
 */
const isValidUrl = (string: string): boolean => {
  try {
    new URL(string);
    return true;
  } catch (_) {
    return false;
  }
};

/**
 * Gets the polling interval based on component status
 */
export const getPollingInterval = (status: ComponentStatus): number => {
  switch (status) {
    case 'validating':
      return 2000; // 2 seconds for validation
    case 'building':
      return 5000; // 5 seconds for building (longer process)
    default:
      return 0; // No polling needed
  }
};

/**
 * Formats component status for display
 */
export const formatComponentStatus = (status: ComponentStatus): string => {
  switch (status) {
    case 'validating':
      return 'Validating';
    case 'valid':
      return 'Valid';
    case 'invalid':
      return 'Invalid';
    case 'building':
      return 'Building';
    case 'ready':
      return 'Ready';
    case 'failed':
      return 'Failed';
    default:
      return 'Unknown';
  }
};

/**
 * Gets user-friendly status description
 */
export const getStatusDescription = (status: ComponentStatus): string => {
  switch (status) {
    case 'validating':
      return 'Component is being validated (repo check, Dockerfile analysis)';
    case 'valid':
      return 'Component validation passed and is ready for builds';
    case 'invalid':
      return 'Component validation failed';
    case 'building':
      return 'Component is currently being built into a container image';
    case 'ready':
      return 'Component built successfully and ready for deployment';
    case 'failed':
      return 'Component build failed';
    default:
      return 'Unknown component status';
  }
};
