// Utility for delayed component status fetching with retry mechanism
import { BaseRecord } from "@refinedev/core";

interface RetryConfig {
  maxRetries?: number;
  delayMs?: number;
  backoffMultiplier?: number;
}

export const delayedComponentFetch = async (
  fetchFunction: () => Promise<any>,
  config: RetryConfig = {}
): Promise<any> => {
  const {
    maxRetries = 3,
    delayMs = 1000,
    backoffMultiplier = 1.5
  } = config;

  let currentDelay = delayMs;
  let lastError: any;

  for (let attempt = 0; attempt <= maxRetries; attempt++) {
    try {
      // Add delay before first attempt (important for component creation)
      if (attempt === 0) {
        await new Promise(resolve => setTimeout(resolve, delayMs));
      }

      const result = await fetchFunction();
      return result;
    } catch (error) {
      lastError = error;
      console.warn(`Component fetch attempt ${attempt + 1} failed:`, error);

      if (attempt < maxRetries) {
        console.log(`Retrying in ${currentDelay}ms...`);
        await new Promise(resolve => setTimeout(resolve, currentDelay));
        currentDelay *= backoffMultiplier;
      }
    }
  }

  throw lastError;
};

export const withComponentStatusRetry = <T extends { status?: string }>(
  component: T,
  retryFunction: () => Promise<T>
): Promise<T> => {
  // If component status is undefined, null, or indicates it might not be ready yet
  if (!component.status || component.status === 'validating' || component.status === 'in_progress') {
    return delayedComponentFetch(retryFunction, {
      maxRetries: 5,
      delayMs: 1000,
      backoffMultiplier: 1.2
    });
  }
  
  return Promise.resolve(component);
};
